# @(#)03  1.8 src/cmdline/staging/scripts/delete_federations.py, amws.cmdline, fim611, 060921a 9/18/06 16:18:25
# (C) Copyright International Business Machines Corporation 2005. All rights
# reserved.  U.S. Government Users Restricted Rights -- Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 
import sys, fim_base
from fed_utils import delete_federations
from domain_utils import is_domain_present
from com.tivoli.am.fim.logging import FIMLoggerFactory
from com.tivoli.am.fim.logging import FIMLogger
from com.tivoli.am.fim.logging import FIMLevel
from com.tivoli.am.fim.i18n.msgs import CmdLineMessages
from jarray import array
from java.lang import Object
from com.tivoli.am.fim.logging import FIMLoggerConstants

# Set up FIMLogger
component_name = "StagingTools"
script_name = "delete_federations.py"
method_name = script_name
class_name = "com.tivoli.am.fim.cmdline." + script_name[0:-3]
FIMLoggerFactory.enableStdout(FIMLevel.ALL)
FIMLoggerFactory.setPreferredFIMLoggerImpl(FIMLoggerConstants.FIMLOGGER_BASE_IMPL)
log = FIMLoggerFactory.getFIMLogger(component_name, class_name, CmdLineMessages.CLASS_NAME)

def usage():
    inserts = array([script_name],Object)
    log.logMessage(FIMLevel.INFO, method_name, CmdLineMessages.usage_delete_federations, \
        inserts)
    raise SystemExit


def delete_all_feds(fed_mgr, sec_tok_mgr):
    id_list = []
    for fed_desc in fed_mgr.listAllFederationDescriptors():
        id_list.append(fed_desc.getId())        
    
    delete_federations(id_list, fed_mgr, sec_tok_mgr)
            
def delete_one_fed(fed_mgr, sec_tok_mgr, fed_id):
    id_list = [fed_id]
    delete_federations(id_list, fed_mgr, sec_tok_mgr)    

if __name__ == 'main':

    if len(sys.argv) < 2:
        usage()
        
    props_file = sys.argv[0]
    domain_props = fim_base.read_properties_file(props_file)
    if not is_domain_present(domain_props):
        raise SystemExit
    
    if (sys.argv[1] == "-all"):
        (fed_mgr, sec_tok_mgr) = fim_base.prepare_mgr_objs(domain_props, "delete_federations")
        delete_all_feds(fed_mgr, sec_tok_mgr) # delete all federations managed by fed_mgr
        inserts = array([domain_props["Domain"]], Object)
        log.logMessage(FIMLevel.INFO, method_name, \
            CmdLineMessages.deleted_all_federations_in_domain, inserts)        
        fim_base.commit_session(fed_mgr)        
    else:
        fed_name = sys.argv[1] # this case is for deleting one federation
        (fed_mgr, sec_tok_mgr) = fim_base.prepare_mgr_objs(domain_props, "delete_federations")

        if not fed_mgr.hasFederationDisplayName(fed_name):
            inserts = array([fed_name, domain_props["Domain"]], Object)
            log.logMessage(FIMLevel.INFO, method_name, \
                CmdLineMessages.federation_does_not_exist_in_domain, inserts)
            raise SystemExit
        fed = fed_mgr.getFederationByDisplayName(fed_name, sec_tok_mgr)
        fed_id = fed.getFederationId()
        delete_one_fed(fed_mgr, sec_tok_mgr, fed_id) # delete the given federation

        # Check to see if the federation got deleted and print results
        if not fed_mgr.hasFederationDisplayName(fed_name): 
            inserts = array([fed_name, domain_props["Domain"]], Object)
            log.logMessage(FIMLevel.INFO, method_name, \
                CmdLineMessages.deleted_federation_in_domain, inserts)
        else:
            inserts = array([fed_name, domain_props["Domain"]], Object)
            log.logMessage(FIMLevel.WARNING, method_name, \
                CmdLineMessages.unable_to_delete_federation_in_domain, inserts)
            
        
        fim_base.commit_session(fed_mgr)

